@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/clients/tools/ldapsearch.c,v 1.37.2.21 2001/05/06 20:07:47 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/clients/tools/ldapsearch.c,v 1.37.2.22 2001/05/17 22:54:03 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -906,7 +906,7 @@ static int dosearch(
 		sprintf( filter, filtpatt, value );
 
 		if ( verbose ) {
-			fprintf( stderr, "filter is: (%s)\n", filter );
+			fprintf( stderr, "filter: %s\n", filter );
 		}
 
 		if( ldif < 2 ) {
