@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/libraries/libldap/search.c,v 1.22.2.5 2000/08/18 02:32:54 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/libldap/search.c,v 1.22.2.7 2000/10/30 17:24:55 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -96,6 +96,9 @@ ldap_search_ext(
 
 	Debug( LDAP_DEBUG_TRACE, "ldap_search_ext\n", 0, 0, 0 );
 
+	assert( ld != NULL );
+	assert( LDAP_VALID( ld ) );
+
 	/*
 	 * if timeout is provided, both tv_sec and tv_usec must
 	 * be non-zero
@@ -207,6 +210,9 @@ ldap_search(
 
 	Debug( LDAP_DEBUG_TRACE, "ldap_search\n", 0, 0, 0 );
 
+	assert( ld != NULL );
+	assert( LDAP_VALID( ld ) );
+
 	ber = ldap_build_search_req( ld, base, scope, filter, attrs,
 	    attrsonly, NULL, NULL, -1, -1 ); 
 
@@ -753,38 +759,39 @@ put_simple_filter(
 
 			if( dn == NULL ) {
 				if(! ldap_is_attr_desc( str ) ) goto done;
-				break;
-			}
+			} else {
 
-			*dn++ = '\0';
-			rule = strchr( dn, ':' );
+				*dn++ = '\0';
+				rule = strchr( dn, ':' );
 
-			if( rule == NULL ) {
-				/* one colon */
-				if ( strcmp(dn, "dn") == 0 ) {
-					/* must have attribute */
-					if( !ldap_is_attr_desc( str ) ) {
+				if( rule == NULL ) {
+					/* one colon */
+					if ( strcmp(dn, "dn") == 0 ) {
+						/* must have attribute */
+						if( !ldap_is_attr_desc( str ) ) {
+							goto done;
+						}
+
+						rule = "";
+
+					} else {
+					  rule = dn;
+					  dn = NULL;
+					}
+				
+				} else {
+					/* two colons */
+					*rule++ = '\0';
+
+					if ( strcmp(dn, "dn") != 0 ) {
+						/* must have "dn" */
 						goto done;
 					}
-
-					rule = "";
-
-				} else {
-					rule = dn;
-					dn = NULL;
 				}
-				
-			} else {
-				/* two colons */
-				*rule++ = '\0';
 
-				if ( strcmp(dn, "dn") != 0 ) {
-					/* must have "dn" */
-					goto done;
-				}
 			}
 
-			if ( *str == '\0' && *rule == '\0' ) {
+			if ( *str == '\0' && ( !rule || *rule == '\0' ) ) {
 				/* must have either type or rule */
 				goto done;
 			}
@@ -793,13 +800,13 @@ put_simple_filter(
 				goto done;
 			}
 
-			if ( *rule != '\0' && !ldap_is_attr_oid( rule ) ) {
+			if ( rule && *rule != '\0' && !ldap_is_attr_oid( rule ) ) {
 				goto done;
 			}
 
 			rc = ber_printf( ber, "t{" /*}*/, ftype );
 
-			if( rc != -1 && *rule != '\0' ) {
+			if( rc != -1 && rule && *rule != '\0' ) {
 				rc = ber_printf( ber, "ts", LDAP_FILTER_EXT_OID, rule );
 			}
 			if( rc != -1 && *str != '\0' ) {
@@ -818,7 +825,7 @@ put_simple_filter(
 				}
 			}
 		}
-		break;
+		goto done;
 
 	default:
 		if ( ldap_pvt_find_wildcard( value ) == NULL ) {
