@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/libraries/liblutil/passwd.c,v 1.12.4.6 2000/09/07 00:11:25 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/libraries/liblutil/passwd.c,v 1.12.4.7 2000/10/30 16:40:10 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -521,9 +521,10 @@ static int chk_smd5(
 	/* hash credentials with salt */
 	lutil_MD5Init(&MD5context);
 	lutil_MD5Update(&MD5context,
-		(const unsigned char *) cred->bv_val, cred->bv_len );
+		(const unsigned char *) cred->bv_val,
+		cred->bv_len );
 	lutil_MD5Update(&MD5context,
-		(const unsigned char *) &orig_pass[sizeof(MD5digest)],
+		&orig_pass[sizeof(MD5digest)],
 		rc - sizeof(MD5digest));
 	lutil_MD5Final(MD5digest, &MD5context);
 
@@ -558,7 +559,8 @@ static int chk_md5(
 	/* hash credentials with salt */
 	lutil_MD5Init(&MD5context);
 	lutil_MD5Update(&MD5context,
-		(const unsigned char *) cred->bv_val, cred->bv_len );
+		(const unsigned char *) cred->bv_val,
+		cred->bv_len );
 	lutil_MD5Final(MD5digest, &MD5context);
 
 	/* compare */
