@@ -1,4 +1,4 @@
-/* $OpenLDAP: pkg/ldap/servers/slapd/main.c,v 1.77.2.8 2000/10/11 02:50:15 kurt Exp $ */
+/* $OpenLDAP: pkg/ldap/servers/slapd/main.c,v 1.77.2.9 2001/01/03 23:17:03 kurt Exp $ */
 /*
  * Copyright 1998-2000 The OpenLDAP Foundation, All Rights Reserved.
  * COPYING RESTRICTIONS APPLY, see COPYRIGHT file
@@ -490,10 +490,10 @@ wait4child( int sig )
 #ifdef WNOHANG
     errno = 0;
 #ifdef HAVE_WAITPID
-    while ( waitpid( (pid_t)-1, NULL, WNOHANG ) >= 0 || errno == EINTR )
+    while ( waitpid( (pid_t)-1, NULL, WNOHANG ) > 0 || errno == EINTR )
 	;	/* NULL */
 #else
-    while ( wait3( NULL, WNOHANG, NULL ) >= 0 || errno == EINTR )
+    while ( wait3( NULL, WNOHANG, NULL ) > 0 || errno == EINTR )
 	;	/* NULL */
 #endif
 #else
